@@ -1,7 +1,7 @@
 package App::td;
 
 our $DATE = '2019-01-16'; # DATE
-our $VERSION = '0.090'; # VERSION
+our $VERSION = '0.091'; # VERSION
 
 use 5.010001;
 #IFUNBUILT
@@ -184,7 +184,7 @@ _
 
         exclude_columns => {
             'x.name.is_plural' => 1,
-            'x.name.singular' => ['exclude_column'],
+            'x.name.singular' => 'exclude_column',
             schema => ['array*', of=>'str*'],
             cmdline_aliases => {e=>{}},
             tags => ['category:select-action'],
@@ -446,7 +446,7 @@ App::td - Manipulate table data
 
 =head1 VERSION
 
-This document describes version 0.090 of App::td (from Perl distribution App-td), released on 2019-01-16.
+This document describes version 0.091 of App::td (from Perl distribution App-td), released on 2019-01-16.
 
 =head1 FUNCTIONS
 
